Taika Documentation
===================

You want a full overview of the documentation? Take a look at the :doc:`contents`.

Getting started
---------------

* Some basics: :doc:`introduction/overview` | :doc:`introduction/installation`
* Up and running!: :doc:`introduction/tutorial/`


Extensions
----------

Add more functionality to your site with extensions!

Check the builtin extensions:

* :doc:`extensions/layouts`
* :doc:`extensions/rst`

Or they don't fit your needs, :doc:`create your own extension<extensions/create>`.


API reference
-------------

Check the :doc:`configuration reference <reference/conf>`.

How Taika works? Take a look at the :doc:`reference/index`.



Taika itself
------------

How is Taika managed and how you can contribute to it.

:doc:`internals/contributing`
